@@ -812,11 +812,11 @@ class WordToken(caching.base.CachingMixin,models.Model):
             prev_context = self.get_previous_context(window = int(window))
         else:
             prev_context = self.get_previous_context()
-        prev_context = filter(lambda x: x is not None,[ x.get_sense(disambiguate=disambiguate).replace('.','#') for x in prev_context if str(x) != str(self)])
-        sense = self.get_sense(disambiguate=disambiguate).replace('.','#')
+        prev_context = filter(lambda x: x is not None,[ x.get_sense(disambiguate=disambiguate) for x in prev_context if str(x) != str(self)])
+        sense = self.get_sense(disambiguate=disambiguate)
         if sense is None:
             return 'NA'
-        sp = perl_get_semantic_predictability(sense,prev_context)
+        sp = perl_get_semantic_predictability(sense.replace('.','#'),map(lambda x: x.replace('.','#'),prev_context))
         #sp = SEM_PRED.get_semantic_predictability(sense,prev_context,style=style)
         if style == 'A' and window == 'A':
             self.PrevSemPred = sp
